/* desktop-input-synthesizer-version.h.in
 *
 * Copyright 2018 Christoph Haag
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE X CONSORTIUM BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * Except as contained in this notice, the name(s) of the above copyright
 * holders shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in this Software without prior written
 * authorization.
 */

#ifndef DESKTOP_INPUT_SYNTHESIZER_VERSION_H
#define DESKTOP_INPUT_SYNTHESIZER_VERSION_H

#if !defined(DESKTOP_INPUT_SYNTHESIZER_INSIDE) && !defined(DESKTOP_INPUT_SYNTHESIZER_COMPILATION)
# error "Only <desktop-input-synthesizer.h> can be included directly."
#endif

/**
 * SECTION:desktop-input-synthesizerversion
 * @short_description: desktop-input-synthesizer version checking
 *
 * desktop-input-synthesizer provides macros to check the version of the library
 * at compile-time
 */

/**
 * DESKTOP_INPUT_SYNTHESIZER_MAJOR_VERSION:
 *
 * desktop-input-synthesizer major version component (e.g. 1 if %DESKTOP_INPUT_SYNTHESIZER_VERSION is 1.2.3)
 */
#define DESKTOP_INPUT_SYNTHESIZER_MAJOR_VERSION (0)

/**
 * DESKTOP_INPUT_SYNTHESIZER_MINOR_VERSION:
 *
 * desktop-input-synthesizer minor version component (e.g. 2 if %DESKTOP_INPUT_SYNTHESIZER_VERSION is 1.2.3)
 */
#define DESKTOP_INPUT_SYNTHESIZER_MINOR_VERSION (12)

/**
 * DESKTOP_INPUT_SYNTHESIZER_MICRO_VERSION:
 *
 * desktop-input-synthesizer micro version component (e.g. 3 if %DESKTOP_INPUT_SYNTHESIZER_VERSION is 1.2.3)
 */
#define DESKTOP_INPUT_SYNTHESIZER_MICRO_VERSION (1)

/**
 * DESKTOP_INPUT_SYNTHESIZER_VERSION
 *
 * desktop-input-synthesizer version.
 */
#define DESKTOP_INPUT_SYNTHESIZER_VERSION (0.12.1)

/**
 * DESKTOP_INPUT_SYNTHESIZER_VERSION_S:
 *
 * desktop-input-synthesizer version, encoded as a string, useful for printing and
 * concatenation.
 */
#define DESKTOP_INPUT_SYNTHESIZER_VERSION_S "0.12.1"

#define DESKTOP_INPUT_SYNTHESIZER_ENCODE_VERSION(major,minor,micro) \
        ((major) << 24 | (minor) << 16 | (micro) << 8)

/**
 * DESKTOP_INPUT_SYNTHESIZER_VERSION_HEX:
 *
 * desktop-input-synthesizer version, encoded as an hexadecimal number, useful for
 * integer comparisons.
 */
#define DESKTOP_INPUT_SYNTHESIZER_VERSION_HEX \
        (DESKTOP_INPUT_SYNTHESIZER_ENCODE_VERSION (DESKTOP_INPUT_SYNTHESIZER_MAJOR_VERSION, DESKTOP_INPUT_SYNTHESIZER_MINOR_VERSION, DESKTOP_INPUT_SYNTHESIZER_MICRO_VERSION))

/**
 * DESKTOP_INPUT_SYNTHESIZER_CHECK_VERSION:
 * @major: required major version
 * @minor: required minor version
 * @micro: required micro version
 *
 * Compile-time version checking. Evaluates to %TRUE if the version
 * of desktop-input-synthesizer is greater than the required one.
 */
#define DESKTOP_INPUT_SYNTHESIZER_CHECK_VERSION(major,minor,micro)   \
        (DESKTOP_INPUT_SYNTHESIZER_MAJOR_VERSION > (major) || \
         (DESKTOP_INPUT_SYNTHESIZER_MAJOR_VERSION == (major) && DESKTOP_INPUT_SYNTHESIZER_MINOR_VERSION > (minor)) || \
         (DESKTOP_INPUT_SYNTHESIZER_MAJOR_VERSION == (major) && DESKTOP_INPUT_SYNTHESIZER_MINOR_VERSION == (minor) && \
          DESKTOP_INPUT_SYNTHESIZER_MICRO_VERSION >= (micro)))

#endif /* DESKTOP_INPUT_SYNTHESIZER_VERSION_H */

